==> doctrine_2.7.2.orig.tar.xz: doctrine-2.7.2/tests/Doctrine/Tests/ORM/Functional/SchemaTool/CompanySchemaTest.php <==
<?php

namespace Doctrine\Tests\ORM\Functional\SchemaTool;

use Doctrine\DBAL\Schema\Schema;
use Doctrine\Tests\Models\Company\CompanyManager;
use Doctrine\Tests\OrmFunctionalTestCase;

/**
 * Functional tests for the Class Table Inheritance mapping strategy.
 *
 * @author robo
 */
class CompanySchemaTest extends OrmFunctionalTestCase
{
    protected function setUp()
    {
        $this->useModelSet('company');
        parent::setUp();
    }

    /**
     * @group DDC-966
     * @return Schema
     */
    public function testGeneratedSchema()
    {
        $schema = $this->_em->getConnection()->getSchemaManager()->createSchema();

        $this->assertTrue($schema->hasTable('company_contracts'));

        return $schema;
    }

    /**
     * @group DDC-966
     * @depends testGeneratedSchema
     */
    public function testSingleTableInheritance(Schema $schema)
    {
        $table = $schema->getTable('company_contracts');

        // Check nullability constraints
        $this->assertTrue($table->getColumn('id')->getNotnull());
        $this->assertTrue($table->getColumn('completed')->getNotnull());
        $this->assertFalse($table->getColumn('salesPerson_id')->getNotnull());
        $this->assertTrue($table->getColumn('discr')->getNotnull());
        $this->assertFalse($table->getColumn('fixPrice')->getNotnull());
        $this->assertFalse($table->getColumn('hoursWorked')->getNotnull());
        $this->assertFalse($table->getColumn('pricePerHour')->getNotnull());
        $this->assertFalse($table->getColumn('maxPrice')->getNotnull());
    }

    /**
     * @group DBAL-115
     */
    public function testDropPartSchemaWithForeignKeys()
    {
        if (!$this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
            $this->markTestSkipped("Foreign Key test");
        }

        $sql = $this->_schemaTool->getDropSchemaSQL(
            [
            $this->_em->getClassMetadata(CompanyManager::class),
            ]
        );
        $this->assertEquals(4, count($sql));
    }
}

==> doctrine_2.8.1+dfsg.orig.tar.xz: doctrine-2.8.1+dfsg/tests/Doctrine/Tests/ORM/Functional/SchemaTool/CompanySchemaTest.php <==
<?php

namespace Doctrine\Tests\ORM\Functional\SchemaTool;

use Doctrine\DBAL\Schema\Schema;
use Doctrine\Tests\Models\Company\CompanyManager;
use Doctrine\Tests\OrmFunctionalTestCase;

/**
 * Functional tests for the Class Table Inheritance mapping strategy.
 *
 * @author robo
 */
class CompanySchemaTest extends OrmFunctionalTestCase
{
    protected function setUp() : void
    {
        $this->useModelSet('company');
        parent::setUp();
    }

    /**
     * @group DDC-966
     * @return Schema
     */
    public function testGeneratedSchema()
    {
        $schema = $this->_em->getConnection()->getSchemaManager()->createSchema();

        $this->assertTrue($schema->hasTable('company_contracts'));

        return $schema;
    }

    /**
     * @group DDC-966
     * @depends testGeneratedSchema
     */
    public function testSingleTableInheritance(Schema $schema)
    {
        $table = $schema->getTable('company_contracts');

        // Check nullability constraints
        $this->assertTrue($table->getColumn('id')->getNotnull());
        $this->assertTrue($table->getColumn('completed')->getNotnull());
        $this->assertFalse($table->getColumn('salesPerson_id')->getNotnull());
        $this->assertTrue($table->getColumn('discr')->getNotnull());
        $this->assertFalse($table->getColumn('fixPrice')->getNotnull());
        $this->assertFalse($table->getColumn('hoursWorked')->getNotnull());
        $this->assertFalse($table->getColumn('pricePerHour')->getNotnull());
        $this->assertFalse($table->getColumn('maxPrice')->getNotnull());
    }

    /**
     * @group DBAL-115
     */
    public function testDropPartSchemaWithForeignKeys()
    {
        if (!$this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
            $this->markTestSkipped("Foreign Key test");
        }

        $sql = $this->_schemaTool->getDropSchemaSQL(
            [
            $this->_em->getClassMetadata(CompanyManager::class),
            ]
        );
        $this->assertEquals(4, count($sql));
    }
}
